@@ -11,7 +11,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/golangci/golangci-lint/pkg/config"
-	"github.com/golangci/golangci-lint/pkg/golinters"
+	"github.com/golangci/golangci-lint/pkg/golinters/nolintlint"
 	"github.com/golangci/golangci-lint/pkg/lint/lintersdb"
 	"github.com/golangci/golangci-lint/pkg/logutils"
 	"github.com/golangci/golangci-lint/pkg/result"
@@ -34,7 +34,9 @@ func newNolint2FileIssue(line int) result.Issue {
 }
 
 func newTestNolintProcessor(log logutils.Log) *Nolint {
-	return NewNolint(log, lintersdb.NewManager(nil, nil), nil)
+	dbManager, _ := lintersdb.NewManager(log, config.NewDefault(), lintersdb.NewLinterBuilder())
+
+	return NewNolint(log, dbManager, nil)
 }
 
 func getMockLog() *logutils.MockLog {
@@ -190,7 +192,7 @@ func TestNolintAliases(t *testing.T) {
 }
 
 func TestIgnoredRangeMatches(t *testing.T) {
-	var testcases = []struct {
+	testcases := []struct {
 		doc      string
 		issue    result.Issue
 		linters  []string
@@ -283,11 +285,11 @@ func TestNolintUnused(t *testing.T) {
 		enabledSetLog.On("Infof", "Active %d linters: %s", len(enabledLinters), enabledLinters)
 
 		cfg := &config.Config{Linters: config.Linters{DisableAll: true, Enable: enabledLinters}}
-		dbManager := lintersdb.NewManager(cfg, nil)
 
-		enabledLintersSet := lintersdb.NewEnabledSet(dbManager, lintersdb.NewValidator(dbManager), enabledSetLog, cfg)
+		dbManager, err := lintersdb.NewManager(enabledSetLog, cfg, lintersdb.NewLinterBuilder())
+		require.NoError(t, err)
 
-		enabledLintersMap, err := enabledLintersSet.GetEnabledLintersMap()
+		enabledLintersMap, err := dbManager.GetEnabledLintersMap()
 		require.NoError(t, err)
 
 		return NewNolint(log, dbManager, enabledLintersMap)
@@ -299,7 +301,7 @@ func TestNolintUnused(t *testing.T) {
 			Filename: fileName,
 			Line:     3,
 		},
-		FromLinter:           golinters.NoLintLintName,
+		FromLinter:           nolintlint.LinterName,
 		ExpectNoLint:         true,
 		ExpectedNoLintLinter: "varcheck",
 	}
@@ -310,7 +312,7 @@ func TestNolintUnused(t *testing.T) {
 			Filename: fileName,
 			Line:     5,
 		},
-		FromLinter:           golinters.NoLintLintName,
+		FromLinter:           nolintlint.LinterName,
 		ExpectNoLint:         true,
 		ExpectedNoLintLinter: "varcheck",
 	}
@@ -347,11 +349,13 @@ func TestNolintUnused(t *testing.T) {
 		enabledSetLog.On("Infof", "Active %d linters: %s", 1, []string{"nolintlint"})
 
 		cfg := &config.Config{Linters: config.Linters{DisableAll: true, Enable: []string{"nolintlint"}}}
-		dbManager := lintersdb.NewManager(cfg, nil)
-		enabledLintersSet := lintersdb.NewEnabledSet(dbManager, lintersdb.NewValidator(dbManager), enabledSetLog, cfg)
 
-		enabledLintersMap, err := enabledLintersSet.GetEnabledLintersMap()
+		dbManager, err := lintersdb.NewManager(enabledSetLog, cfg, lintersdb.NewLinterBuilder())
 		require.NoError(t, err)
+
+		enabledLintersMap, err := dbManager.GetEnabledLintersMap()
+		require.NoError(t, err)
+
 		p := NewNolint(log, dbManager, enabledLintersMap)
 		defer p.Finish()
 
